NAME

Mail::Transport::Exim - transmit messages using external Exim program

INHERITANCE

Mail::Transport::Exim
  is a Mail::Transport::Send
  is a Mail::Transport
  is a Mail::Reporter

SYNOPSIS

my $sender = Mail::Transport::Exim->new(...);
$sender->send($message);

DESCRIPTION

Implements mail transport using the external 'Exim' program. When instantiated, the mailer will look for the binary in specific system directories, and the first version found is taken.

METHODS

Constructors

Mail::Transport::Exim->new(OPTIONS)

If you have Exim installed in a non-standard location, you will need to specify the path, using new(proxy).

Option      Defined in       Default       
executable  L<Mail::Transport>  C<undef>      
hostname    L<Mail::Transport>  C<'localhost'>
interval    L<Mail::Transport>  C<30>         
log         L<Mail::Reporter>  C<'WARNINGS'> 
password    L<Mail::Transport>  undef         
port        L<Mail::Transport>  undef         
proxy       L<Mail::Transport>  undef         
retry       L<Mail::Transport>  <false>       
timeout     L<Mail::Transport>  C<120>        
trace       L<Mail::Reporter>  C<'WARNINGS'> 
username    L<Mail::Transport>  undef         
via         L<Mail::Transport>  C<'exim'>     

. executable FILENAME

. hostname HOSTNAME|ARRAY-OF-HOSTNAMES

. interval SECONDS

. log LEVEL

. password STRING

. port INTEGER

. proxy PATH

. retry NUMBER|undef

. timeout SECONDS

. trace LEVEL

. username STRING

. via CLASS|NAME

Sending mail

$obj->destinations(MESSAGE, [ADDRESS|ARRAY-OF-ADDRESSES])

See "Sending mail" in Mail::Transport::Send

$obj->putContent(MESSAGE, FILEHANDLE, OPTIONS)

See "Sending mail" in Mail::Transport::Send

$obj->send(MESSAGE, OPTIONS)

See "Sending mail" in Mail::Transport::Send

$obj->trySend(MESSAGE, OPTIONS)

Server connection

$obj->findBinary(NAME [, DIRECTORIES])

See "Server connection" in Mail::Transport

$obj->remoteHost

See "Server connection" in Mail::Transport

$obj->retry

See "Server connection" in Mail::Transport

Error handling

$obj->AUTOLOAD

See "Error handling" in Mail::Reporter

$obj->defaultTrace([LEVEL, [LEVEL])

Mail::Transport::Exim->defaultTrace([LEVEL, [LEVEL])

See "Error handling" in Mail::Reporter

$obj->errors

See "Error handling" in Mail::Reporter

$obj->log([LEVEL [,STRINGS]])

Mail::Transport::Exim->log([LEVEL [,STRINGS]])

See "Error handling" in Mail::Reporter

$obj->logPriority(LEVEL)

Mail::Transport::Exim->logPriority(LEVEL)

See "Error handling" in Mail::Reporter

$obj->logSettings

See "Error handling" in Mail::Reporter

$obj->notImplemented

See "Error handling" in Mail::Reporter

$obj->report([LEVEL])

See "Error handling" in Mail::Reporter

$obj->reportAll([LEVEL])

See "Error handling" in Mail::Reporter

$obj->trace([LEVEL])

See "Error handling" in Mail::Reporter

$obj->warnings

See "Error handling" in Mail::Reporter

Cleanup

$obj->DESTROY

See "Cleanup" in Mail::Reporter

$obj->inGlobalDestruction

See "Cleanup" in Mail::Reporter

DIAGNOSTICS

Error: Errors when closing Exim mailer $program: $!

The Exim mail transfer agent did start, but was not able to handle the message correctly.

Error: Package $package does not implement $method.

Fatal error: the specific package (or one of its superclasses) does not implement this method where it should. This message means that some other related classes do implement this method however the class at hand does not. Probably you should investigate this and probably inform the author of the package.

REFERENCES

See the MailBox website at http://perl.overmeer.net/mailbox/ for more details.

COPYRIGHTS

Distribution version 2.044. Written by Mark Overmeer (mark@overmeer.net). See the ChangeLog for other contributors.

Copyright (c) 2001-2003 by the author(s). All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.