NAME

Mail::Transport::Mailx - transmit messages using external mailx program

INHERITANCE

Mail::Transport::Mailx
  is a Mail::Transport::Send
  is a Mail::Transport
  is a Mail::Reporter

SYNOPSIS

my $sender = Mail::Transport::Mailx->new(...);
$sender->send($message);

DESCRIPTION

Implements mail transport using the external programs 'mailx', Mail, or 'mail'. When instantiated, the mailer will look for any of these binaries in specific system directories, and the first program found is taken.

WARNING: There are many security issues with mail and mailx. DO NOT USE these commands to send messages which contains data derived from any external source!!!

Under Linux, freebsd, and bsdos the mail, Mail, and mailx names are just links to the same binary. The implementation is very primitive, pre-MIME standard, what may cause many headers to be lost. For these platforms (and probably for other platforms as well), you can better not use this transport mechanism.

METHODS

Constructors

Mail::Transport::Mailx->new(OPTIONS)

Option      Defined in       Default       
executable  L<Mail::Transport>  C<undef>      
hostname    L<Mail::Transport>  C<'localhost'>
interval    L<Mail::Transport>  C<30>         
log         L<Mail::Reporter>  C<'WARNINGS'> 
password    L<Mail::Transport>  undef         
port        L<Mail::Transport>  undef         
proxy       L<Mail::Transport>  undef         
retry       L<Mail::Transport>  <false>       
style                        <autodetect>  
timeout     L<Mail::Transport>  C<120>        
trace       L<Mail::Reporter>  C<'WARNINGS'> 
username    L<Mail::Transport>  undef         
via         L<Mail::Transport>  C<'mailx'>    

. executable FILENAME

. hostname HOSTNAME|ARRAY-OF-HOSTNAMES

. interval SECONDS

. log LEVEL

. password STRING

. port INTEGER

. proxy PATH

. retry NUMBER|undef

. style 'BSD'|'RFC822'

There are two version of the mail program. The newest accepts RFC822 messages, and automagically collect information about where the message is to be send to. The BSD style mail command predates MIME, and expects lines which start with a '~' (tilde) to specify destinations and such. This field is autodetect, however on some platforms both versions of mail can live (like various Linux distributions).

. timeout SECONDS

. trace LEVEL

. username STRING

. via CLASS|NAME

Sending mail

$obj->destinations(MESSAGE, [ADDRESS|ARRAY-OF-ADDRESSES])

See "Sending mail" in Mail::Transport::Send

$obj->putContent(MESSAGE, FILEHANDLE, OPTIONS)

See "Sending mail" in Mail::Transport::Send

$obj->send(MESSAGE, OPTIONS)

See "Sending mail" in Mail::Transport::Send

$obj->trySend(MESSAGE, OPTIONS)

Server connection

$obj->findBinary(NAME [, DIRECTORIES])

See "Server connection" in Mail::Transport

$obj->remoteHost

See "Server connection" in Mail::Transport

$obj->retry

See "Server connection" in Mail::Transport

Error handling

$obj->AUTOLOAD

See "Error handling" in Mail::Reporter

$obj->defaultTrace([LEVEL, [LEVEL])

Mail::Transport::Mailx->defaultTrace([LEVEL, [LEVEL])

See "Error handling" in Mail::Reporter

$obj->errors

See "Error handling" in Mail::Reporter

$obj->log([LEVEL [,STRINGS]])

Mail::Transport::Mailx->log([LEVEL [,STRINGS]])

See "Error handling" in Mail::Reporter

$obj->logPriority(LEVEL)

Mail::Transport::Mailx->logPriority(LEVEL)

See "Error handling" in Mail::Reporter

$obj->logSettings

See "Error handling" in Mail::Reporter

$obj->notImplemented

See "Error handling" in Mail::Reporter

$obj->report([LEVEL])

See "Error handling" in Mail::Reporter

$obj->reportAll([LEVEL])

See "Error handling" in Mail::Reporter

$obj->trace([LEVEL])

See "Error handling" in Mail::Reporter

$obj->warnings

See "Error handling" in Mail::Reporter

Cleanup

$obj->DESTROY

See "Cleanup" in Mail::Reporter

$obj->inGlobalDestruction

See "Cleanup" in Mail::Reporter

DIAGNOSTICS

Error: Package $package does not implement $method.

Fatal error: the specific package (or one of its superclasses) does not implement this method where it should. This message means that some other related classes do implement this method however the class at hand does not. Probably you should investigate this and probably inform the author of the package.

Error: Sending via mailx mailer $program failed: $! ($?)

Mailx (in some shape: there are many different implementations) did start accepting messages, but did not succeed sending it.

REFERENCES

See the MailBox website at http://perl.overmeer.net/mailbox/ for more details.

COPYRIGHTS

Distribution version 2.044. Written by Mark Overmeer (mark@overmeer.net). See the ChangeLog for other contributors.

Copyright (c) 2001-2003 by the author(s). All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.